==> kmyfirewall_1.0.orig.tar.gz: kmyfirewall-1.0/kmyfirewall/kmfwidgets/kmfmultiportwidget.h <==
/***************************************************************************
  begin                : Fri Nov 1 2002
  copyright            : (C) 2002 by Christian Hubinger
  email                : chubinger@gmail.com
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFMULTIPORTWIDGET_H
#define KMFMULTIPORTWIDGET_H

#include <qwidget.h>
#include <kdemacros.h>
#include "kmyfirewallmultiportwidget.h"


class QString;
class KMFError;

/**
  *@author Christian Hubinger
  */

class KDE_EXPORT KMFMultiPortWidget : public KMyFirewallMultiPortWidget {
	Q_OBJECT
public:
	KMFMultiPortWidget( QWidget *parent = 0, const char *name = 0 );
	~KMFMultiPortWidget();

	KMFError* getPortString( QString* value );
	void setType( const QString& type );
	QString& type() const;
	void loadPortString( QString& );
	void reset();

private slots:
	void addPort();
	void addPort( QString& port );
	void removePort();
	void removePort( int index );

private:
	KMFError *m_err;

};

#endif

==> kmyfirewall_1.1.1.orig.tar.gz: kmyfirewall-1.1.1/kmyfirewall/kmfwidgets/kmfmultiportwidget.h <==
/***************************************************************************
  begin                : Fri Nov 1 2002
  copyright            : (C) 2002 by Christian Hubinger
  email                : chubinger@irrsinnig.org
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFMULTIPORTWIDGET_H
#define KMFMULTIPORTWIDGET_H

#include <qwidget.h>
#include <kdemacros.h>
#include "kmyfirewallmultiportwidget.h"


class QString;

namespace KMF {
class KMFError;

/**
  *@author Christian Hubinger
  */

class KDE_EXPORT KMFMultiPortWidget : public KMyFirewallMultiPortWidget {
	Q_OBJECT
public:
	KMFMultiPortWidget( QWidget *parent = 0, const char *name = 0 );
	~KMFMultiPortWidget();

	KMFError* getPortString( QString* value );
	void setType( const QString& type );
	QString& type() const;
	void loadPortString( QString& );
	void reset();

private slots:
	void addPort();
	void addPort( QString& port );
	void removePort();
	void removePort( int index );

private:
	KMFError *m_err;

};
}
#endif
